@@ -141,7 +141,7 @@
 
 /* Define if your processor stores words with the most significant byte
    first (like Motorola and SPARC, unlike Intel and VAX). */
-/* #undef WORDS_BIGENDIAN */
+#define WORDS_BIGENDIAN
 
 /* VA library (libva) */
 /* #undef HAVE_VA */
